@@ -51,7 +51,7 @@ __all__.extend(_jclass.__all__)
 __all__.extend(_jcustomizer.__all__)
 __all__.extend(_gui.__all__)
 
-__version__ = "1.0.2"
+__version__ = "1.1.2"
 __version_info__ = __version__.split('.')
 
 
@@ -63,3 +63,7 @@ javax = JPackage("javax", strict=True)
 
 JMethod = _jpype._JMethod
 JField = _jpype._JField
+
+if hasattr(_jpype, 'bootstrap'):
+   _jpype.bootstrap()
+   _core.initializeResources()
